..  venco.py introdcution file created on February 11, 2020
    Licensed under CC BY 4.0: https://creativecommons.org/licenses/by/4.0/deed.en

.. _contributing:

Contributing to the software
===================================


General information
---------------------

venco.py is a tool that is open for your contribution, and we are thankful for every issue you report. 

If you are interested in contributing to the code, the documentation, have a mobility dataset that may act as an input to venco.py, real charging profiles for validating venco.py output or other contributions, you are gratefully invited to share them. For this, please read, sign and send the Contributors License Agreement (CLA) to Niklas Wulff.

When contributing to the repository, please send us a merge request with a meaningful branch name.

We use git as software versioning tool to maintain and develop venco.py. 
You can make changes to the source code on your local copy of the software and create a merge request to include your changes in the official software. 
Information on merge requests are provided in the `offical GitLab documentation <https://docs.gitlab.com/ee/user/project/merge_requests/>`_.


Maintenance plan
-----------------

The software of venco.py will in its current release version be provided as-is. Minor bug fixes may be released by the software engineering team (SET, see :ref:`architecture`) within the release cycles.
Currently, no major support can be offered to the software. However, feel free to reach out if you have any questions.



